#####################################################################################################################
#                                        REPLICATION DOCUMENT
#                              Mapping the Trade and Environment Nexus: 
#                                   Insights from a New Dataset
#                                              2017

#                        Jean-Frederic Morin, Andreas Duer, and Lisa Lechner

#####################################################################################################################

setwd('~/replication_dossier/')

#-----------------#
# load packages
#-----------------#
source('load.R')

#--------------------#
# read data
#--------------------#
df1 = readRDS('replication_data_figures_I.rds')

# -----------------------------------------------------------------
# Figure 1: The Most Widely Used Environmental Norms in Trade Agreements
# -----------------------------------------------------------------
df2 = readRDS('replication_data_figures_II.rds')

ggdotchart(df2, x = "items_names", y = "freq",
           sorting = "descending",                       
           rotate = TRUE,
           dot.size = 2, 
           ggtheme = theme_pubr())+
  theme_cleveland() +
  ylab("Number of agreements including norm")


# -----------------------------------------------------------------
# Figure 2: Environmental Norms in Trade Agreements over Time and by Level of Development
# -----------------------------------------------------------------
df1 = df1 %>% dplyr::mutate(id=paste(Year,NorthSouth)) %>%
             dplyr::filter(!is.na(NorthSouth)) %>%
             dplyr::mutate(NoSo = ifelse(NorthNorth==1,'North North', 'South South'),
                           NoSo = ifelse(NorthSouth==1, 'North South', NoSo),
                           Label = ifelse(any_item_aggregated>130|
                                            any_item_aggregated>80 & SouthSouth==1|
                                            any_item_aggregated>70 & NorthNorth==1|
                                            Number==636,paste(Name,Year),""),
                           Label = gsub("EC ","EU ",Label),
                           Label = gsub(" EC"," EU",Label)) %>% filter(!is.na(any_item_aggregated))


ggplot(df1, aes(Year,any_item_aggregated,label=Label))+ 
  geom_point(size=2,color="gray70")+  #,color="gray"
  geom_text_repel(data=df1[df1$Label!="",],size=3.1,show.legend = FALSE, min.segment.length = unit(0, "lines"))+
  scale_x_continuous(breaks = round(seq(min(df1$Year), max(df1$Year), by = 3),1))+
  facet_grid(NoSo~.)+
  ylab("Number of environmental items regulated")+xlab("")+  theme_bw()+
  theme(panel.grid.major = element_blank(),
    panel.background = element_blank(),
    axis.text.x = element_text(angle = 90, hjust = 1),
    legend.position = "none") 


# -----------------------------------------------------------------
# Figure 3: Environmental Norms in Trade Agreements (in force) by Country
# -----------------------------------------------------------------
gpclibPermit()
world.map <- readOGR(dsn="Map/", layer="TM_WORLD_BORDERS_SIMPL-0.3")
world.ggmap <- fortify(world.map, region = "NAME")
n <- length(unique(world.ggmap$id))
df2 <- data.frame(id = unique(world.ggmap$id),
                 growth = 4*runif(n),
                 category = factor(sample(1:5, n, replace=T))) %>% 
  mutate(ISO=countrycode(id,"country.name","iso3n"))

df3 = readRDS('replication_data_figures_III.rds') %>%
  mutate(any_item_aggregated = ave(any_item_aggregated,ISO,FUN=function(x) mean(x,na.rm=T)))  %>% #average commitment level of each country
  dplyr::select(ISO,any_item_aggregated) %>% unique

df2 = full_join(df2,df3)
df2 = df2 %>% mutate(any_item_aggregated = ifelse(is.na(any_item_aggregated),0,any_item_aggregated)) %>% 
     dplyr::filter(!is.na(ISO)) %>%
  mutate(any_item_aggregated=ifelse(ISO==620|ISO==826|ISO==470|ISO==380|
                                      ISO==276|ISO==250|ISO==246|ISO==191|ISO==100|ISO==56|
                                      ISO==40|ISO==752|ISO==528|ISO==724|ISO==372|ISO==442|
                                      ISO==208|ISO==100|ISO==191,54,any_item_aggregated))

ggplot(df2, aes(map_id = id)) +
  geom_map(aes(fill = any_item_aggregated), map =world.ggmap) +
  expand_limits(x = world.ggmap$long, y = world.ggmap$lat) +
  scale_fill_gradient(low ="gray95" , high = "dimgray", guide = "colorbar",name="Average number of environmental items in PTAs") +
  xlab("")+ylab("")+  theme_bw()+
  theme(legend.position="bottom",legend.title=element_text(size=10))


# -----------------------------------------------------------------
# Figure 4: Regime Type and Environmental Norms
# -----------------------------------------------------------------

ggplot(df1,aes(polity2max, any_item_aggregated))+
  geom_point()+
  geom_smooth(method='lm',se=T,color="gray40") +
  ylab("Number of environmental items")+
  xlab("Regime Type (0=Autocracy, 20=Democracy)")+
  theme_bw()


# -----------------------------------------------------------------
# Figure 5: Import Competition and Environmental Norms
# -----------------------------------------------------------------
df4 = df1 %>% filter(!is.na(competition))

ggplot(df4,aes(competition, any_item_aggregated))+
  geom_point()+
  geom_smooth(method='lm',se=T,color="gray40") +
  ylab("Number of environmental items")+
  xlab("Import competition")+
  theme_bw()


# -----------------------------------------------------------------
# Figure 6: Pollution and Environmental Norms
# -----------------------------------------------------------------

df5 = df1 %>% dplyr::select(Name,Year,epimax,so2popmin_ln,any_item_aggregated)
df5 = melt(df5,id.vars = c("Name","Year","epimax","so2popmin_ln")) %>%
  mutate(value=ifelse(is.nan(value),NA,value),
         value=ifelse(is.infinite(value),NA,value))


p1 <-ggplot(df5, aes(so2popmin_ln,value))+
  geom_point()+
  geom_smooth(method="lm",se=T,color="gray40")+
  scale_shape_discrete(solid=F) +
  ylab("Number of environmental items")+
  xlab("SO2 Emissions per Capita (log)")+
  theme_bw()+
  theme(legend.position="bottom",legend.title=element_blank())

p2 <-ggplot(df5, aes(epimax,value))+ 
  geom_point()+
  geom_smooth(method="lm",se=T,color="gray40")+
  scale_shape_discrete(solid=F) +
  ylab("Number of environmental items")+
  xlab("Environmental Protection Index")+
  theme_bw()+
  theme(legend.position="bottom",legend.title=element_blank())

multiplot(p1,p2)

